@@ -8,12 +8,11 @@ from nowcasting_dataset.consts import (
     GSP_X_COORDS,
     GSP_Y_COORDS,
     GSP_YIELD,
-    Array,
 )
 from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import Field, validator
 
-from nowcasting_dataloader.data_sources.datasource_output import DataSourceOutputML
+from nowcasting_dataloader.data_sources.datasource_output import Array, DataSourceOutputML
 
 logger = logging.getLogger(__name__)
 
