@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import logging
+from typing import Optional
 
 import numpy as np
 import xarray as xr
@@ -9,7 +10,7 @@ from nowcasting_dataset.time import make_random_time_vectors
 from pydantic import Field
 
 from nowcasting_dataloader.data_sources.datasource_output import Array, DataSourceOutputML
-from nowcasting_dataloader.utils.dims import re_order_dims
+from nowcasting_dataloader.xr_utils import re_order_dims
 
 logger = logging.getLogger(__name__)
 
@@ -75,7 +76,7 @@ class NWPML(DataSourceOutputML):
 
     init_time: Array = Field(..., description="The time when the nwp forecast was made")
 
-    channels: Array = Field(..., description="List of the nwp channels")
+    channels: Optional[Array] = Field(None, description="List of the nwp channels")
 
     @staticmethod
     def fake(
@@ -126,7 +127,7 @@ class NWPML(DataSourceOutputML):
 
         # convert to torch dict
         nwp_batch_ml = xr_dataset.torch.to_tensor(
-            ["data", "time", "init_time", "x", "y", "channels"]
+            ["data", "time", "init_time", "x", "y"]
         )
 
         # make into Model
